@@ -334,14 +334,14 @@ class LIB:
             CIPHER = Fernet(key)
             if action == "E":
                 if type(word == "str"):
-                    result = CIPHER.encrypt(word)
+                    result = CIPHER.encrypt(word).decode()
             else:
-                result = CIPHER.decrypt(word)
+                result = CIPHER.decrypt(word).decode()
         except Exception as error:
             msg = error.args[0]
             result = msg
         finally:
-            return result.decode()
+            return result
 
     @staticmethod
     def cores_ansi() -> dict:
